==> sadad_payment_flutter-0.0.32.tar.gz: lib/controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:sadad_payment_flutter/sadad_payment_flutter.dart';
import 'package:sadad_payment_flutter/services/appservices.dart';

class MainPageController extends GetxController {
  TextEditingController cardHolderNameController = TextEditingController();
  TextEditingController cardNumberController = TextEditingController();
  TextEditingController expiryController = TextEditingController();
  TextEditingController cvvController = TextEditingController();
  TextEditingController cellNumberController = TextEditingController();
  TextEditingController sadadPayPasswordController = TextEditingController();
  PaymentType selectedPaymentMethod = PaymentType.creditCard;
  bool rememberMe = false;
  bool isObscure = true;
  String token = "";

  @override
  void onInit() {
    // TODO: implement onInit
    super.onInit();
    AppServices.getCreditCardSetting(token: token);
  }

  String getCardType(String cardNumber) {
    if (cardNumber.contains(RegExp(r'^(5[1-5][0-9]{4}|677189)[0-9]{5,}$'))) {
      return "Mastercard";
    } else if (cardNumber.contains(RegExp(r'^4[0-9]{6,}([0-9]{3})?$'))) {
      return "Visa";
    } else if (cardNumber.contains(RegExp(r'^3[47][0-9]{5,}$'))) {
      return "Amex";
    } else if (cardNumber.contains(RegExp(r'^(36|38|30[0-5])'))) {
      return "DINERS_CLUB";
    } else if (cardNumber.contains(RegExp(r'^(5018|5020|5038|5[6-9]|6020|6304|6703|6759|676[1-3])'))) {
      return "MAESTRO";
    }
    return "";
  }
}

==> sadad_payment_flutter-0.0.33.tar.gz: lib/controller.dart <==
import 'package:flutter/cupertino.dart';
import 'package:get/get.dart';
import 'package:sadad_payment_flutter/model/creditcardsettingsmodel.dart';
import 'package:sadad_payment_flutter/sadad_payment_flutter.dart';
import 'package:sadad_payment_flutter/services/appservices.dart';

class MainPageController extends GetxController {
  TextEditingController cardHolderNameController = TextEditingController();
  TextEditingController cardNumberController = TextEditingController();
  TextEditingController expiryController = TextEditingController();
  TextEditingController cvvController = TextEditingController();
  TextEditingController cellNumberController = TextEditingController();
  TextEditingController sadadPayPasswordController = TextEditingController();
  PaymentType selectedPaymentMethod = PaymentType.creditCard;
  bool rememberMe = false;
  bool isObscure = true;
  String token = "";
  List<CreditCardSettingsModel> creditCardSettingsModel = [];
  String credit_card_bankpage_type = "";
  String is_american_express = "";
  String is_cybersourse_visa = "";
  String is_cybersourse_mastercard = "";

  @override
  void onInit() {
    // TODO: implement onInit
    super.onInit();
    init();
  }

  String getCardType(String cardNumber) {
    if (cardNumber.contains(RegExp(r'^(5[1-5][0-9]{4}|677189)[0-9]{5,}$'))) {
      return "Mastercard";
    } else if (cardNumber.contains(RegExp(r'^4[0-9]{6,}([0-9]{3})?$'))) {
      return "Visa";
    } else if (cardNumber.contains(RegExp(r'^3[47][0-9]{5,}$'))) {
      return "Amex";
    } else if (cardNumber.contains(RegExp(r'^(36|38|30[0-5])'))) {
      return "DINERS_CLUB";
    } else if (cardNumber.contains(RegExp(r'^(5018|5020|5038|5[6-9]|6020|6304|6703|6759|676[1-3])'))) {
      return "MAESTRO";
    }
    return "";
  }

  Future<void> init() async {
    creditCardSettingsModel = await AppServices.getCreditCardSetting(token: token);
    creditCardSettingsModel.forEach((element) {
      if (element.key == "credit_card_bankpage_type") {
        credit_card_bankpage_type = element.value ?? "";
      } else if (element.key == 'is_american_express') {
        is_american_express = element.value ?? "";
      } else if (element.key == 'is_cybersourse_visa') {
        is_cybersourse_visa = element.value ?? "";
      } else if (element.key == 'is_cybersourse_mastercard') {
        is_cybersourse_mastercard = element.value ?? "";
      }
    });
  }
}
